@@ -494,8 +494,8 @@ This function will create a directory under
 buffer without the extension, if any."
 
   (interactive "P")
-  (when (directory-files greader-audiobook-base-directory nil
-			 (file-name-sans-extension (buffer-name)))
+  (when (file-exists-p (file-name-concat
+			greader-audiobook-base-directory (file-name-sans-extension (buffer-name))))
     (let ((response (yes-or-no-p "This audiobook already
   exists.  Overwrite it?")))
       (if response
@@ -523,7 +523,7 @@ buffer without the extension, if any."
 	(narrow-to-region start-position end-position)
 	(goto-char start-position)
 	(unless (file-exists-p greader-audiobook-base-directory)
-	  (make-directory greader-audiobook-base-directory))
+	  (make-directory greader-audiobook-base-directory t))
 	(let* ((book-directory (concat (file-name-sans-extension
 					(buffer-name))
 				       "/"))
